@@ -67,6 +67,7 @@ class TickerDax:
         self._websocket_api_key = os.environ.get(Envs.WEBSOCKET_API_KEY.value, websocket_api_key)
 
         # redis configuration
+        # Todo match tag with package version
         self._image_name = f'{NAME}/client:latest'
         self._container_name = NAME
         self._redis_server_address = os.environ.get(Envs.REDIS_SERVER_ADDRESS.value, '127.0.0.1')
@@ -80,7 +81,8 @@ class TickerDax:
         # module level dictionary for caching during runtime
         self._runtime_cache = {}
 
-        self._cache_folder = os.environ.get(Envs.CACHE_ROOT.value, os.path.join(tempfile.gettempdir(), f'{NAME}_cache'))
+        self._cache_folder = os.environ.get(Envs.CACHE_ROOT.value, os.path.join(tempfile.gettempdir(), NAME, 'cache'))
+        self._logs_folder = os.environ.get(Envs.LOGS_FOLDER.value, os.path.join(tempfile.gettempdir(), NAME, 'logs'))
         self._logger = logging.getLogger(self.__class__.__name__)
         self._logger.setLevel(level=logging.DEBUG)
 
@@ -210,7 +212,8 @@ class TickerDax:
         console_handler.setFormatter(formatter)
 
         # create log handler for file output
-        file_handler = TimedRotatingFileHandler('tickerdax.log', when='midnight')
+        os.makedirs(self._logs_folder, exist_ok=True)
+        file_handler = TimedRotatingFileHandler(os.path.join(self._logs_folder, 'output.log'), when='midnight')
         file_handler.setFormatter(formatter)
 
         log_level = logging.INFO
